<?php

/**
* Quizzes Controller
*
* @link 		https://entusiastics.com
* @since 		1.0.0
*
* @package 	Entusiastics_Quiz_Game
* @subpackage 	Entusiastics_Quiz_Game/admin/controllers
*/

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class QuizzesController {

	static function manage() {

		$action = filter_input(INPUT_GET, 'action');

		if(empty($action)){
			return false;
		}

		switch($action) {
			case 'add':
			self::index();
			break;
			case 'edit': 
			self::edit();
			break;
			case 'delete': 
			self::delete();
			break;
			case 'copy': 
			self::copy();
			break;
			default:
			self::index();
			break;
		}

	} // end manage()
	
	static function index() {

		$add = filter_input(INPUT_POST, 'ok');
		$request = filter_input_array(INPUT_POST);
		
		if(!empty($add)) {
			self::store($request);
		}
		
		$is_published = false;

		$_category = new Category();

		// select quizz categories for drop-down
		$categories = $_category->getCategories();

		include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH.'admin/partials/entusiastics-quiz-game-quiz.php');

	} // end add_quiz

	static function store($request) {

		$_quiz = new Quiz();
		$_objectives = new Objective();

		try {
			$qid = $_quiz->add($request);

			if($qid) {
				$qobjectives = $_objectives->manage($request, $qid, 'add');
			}

			entusiastics_quiz_game_redirect("admin.php?page=entusiastics-quiz-game-quizzes-list");
			exit;
		}
		catch(Exception $e) {
			$error = $e->getMessage();
		}

	}
	
	static function edit() {

		$quiz_id = filter_input(INPUT_GET, 'id');
		$edit = filter_input(INPUT_POST, 'ok');
		$request = $_POST;

		if(!empty($edit)) {
			self::update($request, $quiz_id);
		}

		$_quiz = new Quiz();
		$_objectives = new Objective();
		$_category = new Category();
		
		// select the quiz
		$quiz = $_quiz->getQuizById($quiz_id);

		// select all categories
		$categories = $_category->getCategories();

		// select quizz category
		$quiz_category = $_category->getCategoryByQuizzId($quiz->category_id);

		// select quizz objectives
		$objectives = $_objectives->getObjectivesByQuizId($quiz->id);

		// is this quiz currently published?
		$is_published = $_quiz->checkIfPublished($quiz_id);

		include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH.'admin/partials/entusiastics-quiz-game-quiz.php');

	} // end edit_quiz

	static function update($request, $quiz_id){

		$_quiz = new Quiz();
		$_objectives = new Objective();

		try {
			$quiz_updated = $_quiz->save($request, $quiz_id);

			if($quiz_updated) {
				$qobjectives = $_objectives->manage($request, $quiz_id);
			}

			entusiastics_quiz_game_redirect("admin.php?page=entusiastics-quiz-game-quizz&action=edit&id=".$quiz_id);
		}
		catch(Exception $e) {
			$error = $e->getMessage();
		}
	}
	
	/**
	 * Displays a quiz in front end
	 *
	 *
	 * @param  	int 		$quiz_id Id of Quizz passed in shortcode
	 * @return 	array 		Array of Quizzes and this questions
	 */
	static function display($quiz_id) {

		global $wpdb, $user_ID, $post;

		$data = [ 
			'quiz' => [],
			'question' => [],
			'first_load' => false,
			'ui' => [],
			'choices' => [],
			'cnt_takings' => [],
			'error'=> '',
			'post' => $post,
			'objectives' => [],
			'related_quizzes' => []
		];

		$_quiz = new Quiz();
		$_objective = new Objective();
		$_completed = new Completed();
		$_question = new Question();

	   	// select the quiz
		$data['quiz'] = $_quiz->getQuizById($quiz_id);

		if(empty($data['quiz']->id)) {
			$data['error'] = 1;
			return $data;
		}

	   	// completion ID already created?
		if(empty($_SESSION['entusiastics_quiz_game_completion_id'])) {
			$_SESSION['entusiastics_quiz_game_completion_id'] = $_completed->checkIfCompletionIsCreated(intval($data['quiz']->id), entusiastics_quiz_game_user_ip(), $user_ID);
		}

		// select all questions for summary
		$data['questions'] = $_question->getQuestionByQuizId($data['quiz']->id);
		
		if(empty($data['questions'])) {
			$data['error'] = 2;
		}

		$data['first_load'] = true;
		$data['ui'] = get_option('entusiastics_quiz_game_ui');

		// select quizz objectives
		$data['objectives'] = $_objective->getObjectivesByQuizId($data['quiz']->id);

		// select quizz objectives
		$data['related_quizzes'] = $_quiz->getRelatedCategoryQuizzes($data['quiz']->id, $data['quiz']->category_id);

		// can re-take?
		if(!empty($data['quiz']->times_to_take)) {
			$data['cnt_takings'] = $_completed->checkIfcanReTake($data['quiz']->id, $user_ID);
		}

		// parse time
		$parsed_duration = entusiastics_quiz_game_parse_time($data['quiz']->duration);
		$data['quiz']->duration = $parsed_duration;

		return $data;
	}

	/**
	 * Start quiz print first question
	 *
	 * @return 	array Array of first quiz question and this choices
	 */
	static function start_quiz() {

		global $user_ID;

		$quiz_id = filter_input(INPUT_POST, 'quiz_id');
		$post = get_post(filter_input(INPUT_POST, 'post_id'));

		$data = [ 
			'quiz' => [],
			'question' => [],
			'first_load' => false,
			'ui' => [],
			'choices' => [],
			'cnt_takings' => [],
			'error'=> '',
			'post' => $post
		];

		$_quiz = new Quiz();
		$_question = new Question();
		$_choice = new Choice();

	   	// select the quiz
		$data['quiz'] =  $_quiz->getQuizById($quiz_id);

		if(empty($data['quiz']->id)) {
			$data['error'] = 1;
			return $data;
		}

		// select the first question
		$data['question'] = $_question->getFirstQuizQuestion($data['quiz']->id);

		// select all questions for summary
		$data['questions'] = $_question->getQuestionByQuizId($data['quiz']->id);	
		
		if(empty($data['question'])) {
			$data['error'] = 2;
			return $data;
		}

		// select possible answers
		$data['choices'] = $_choice->getPossibleAnswers($data['quiz']->id, $data['question']->id);

		$data['first_load'] = true;

		$data['ui'] = get_option('entusiastics_quiz_game_ui');

		echo '|ENTUSIASTICSQUIZGAME|';

		do_action('entusiastics_show_question_template', 'question', $data);
	}

	/**
	 * Answer the question and return next
	 *
	 * @return 	array Array of next question and this choices
	 */
	static function answer_question() {

		global $user_ID;

		$question_id = intval(filter_input(INPUT_POST, 'question_id'));
		$quiz_id = intval(filter_input(INPUT_POST, 'quiz_id'));
		$post = get_post(filter_input(INPUT_POST, 'post_id'));
		$session = intval($_SESSION['entusiastics_quiz_game_completion_id']);
		$profile_id = intval(filter_input(INPUT_POST, 'profile_id'));
		$responsed_questions = [];

		$data = [ 
			'quiz' => [],
			'question' => [],
			'questions' => [],
			'answer' => [],
			'choices' => [],
			'post' => $post,
			'ui' => [],
			'choice' => [],
			'first_load' => false
		];

		$_quiz = new Quiz();
		$_question = new Question();
		$_completed = new Completed();
		$_user_answer = new UserAnswer();
		$_choice = new Choice();

		// select quiz
		$data['quiz'] = $_quiz->getQuizById($quiz_id);

		// select question
		$data['question'] = $_question->getQuestionById($question_id);

		// prepare $answer var		
		$answer = ($data['question']->qtype == 'checkbox') ? @$_POST['answers'] : @$_POST['answer'];

		if(empty($answer)){
			$answer = 0;
		}

		$answer = esc_sql($answer);

		// figure out next question
		$next_question = $_question->next($data['question'], $answer);

		// store the answer
		if(!empty($session)) {

			if(is_array($answer)) {
				$answer = entusiastics_quiz_game_int_array($answer);
				$answer = implode(",", $answer);
			}

			// make sure to avoid duplicates and only update the answer if it already exists
			$exists = $_user_answer->checkIfAnswerExists($data['quiz']->id, $session, $data['question']->id);

			if($exists) {
				// update answer
				$updated = $_user_answer->update($answer, $data['quiz']->id, $session, $data['question']->id, $profile_id);
			}
			else {
				// save answer
				$stored = $_user_answer->save($data['quiz']->id, $session, $data['question']->id, $answer, $profile_id);
			}

			// update the "completed" record as non empty
			$_completed->update($session);
		}

		array_push($_SESSION['responsed_questions'], $data['question']); 

		// select all questions for summary
		$data['questions'] = $_question->getQuestionByQuizId($data['quiz']->id);

		if(!empty($next_question->id)) {

			$data['question'] = $next_question;
			$data['choices'] = $_choice->getPossibleAnswers($quiz_id, $data['question']->id);
			$data['ui'] = get_option('entusiastics_quiz_game_ui');

			echo '|ENTUSIASTICSQUIZGAME|';

			do_action('entusiastics_show_question_template', 'question', $data);
			
		} else {

			$data['choice'] = $_choice->getAnswerById($answer);

			if($data['choice']->video_url) {

				$data['ui'] = get_option('entusiastics_quiz_game_ui');
				
				echo '|ENTUSIASTICSQUIZGAME|';

				do_action('entusiastics_show_video_template', 'video', $data);

			} else {

				self::finalize($data['quiz']); // if none, submit the quiz

			}	

		}

	}

	static function finalize($quiz, $sesion_completion_id = null) {

		$_SESSION['responsed_questions'] = [];

		$args = [
			'quiz' => [],
			'user_id' => 0,
			'completion_id' => intval(@$_SESSION['entusiastics_quiz_game_completion_id']),
			'source_url' => '',
			'taking_id' => '',
			'output' => '',
			'completed' => [],
			'user_answers' => [],
			'results' => [],
			'results_positive' => [],
			'results_negative' => [],
			'results_no_profile' => [],
			'redirect_url' => ''
		];

		$_completed = new Completed();
		$_user_answer = new UserAnswer();
		$_quiz = new Quiz();
		$_question = new Question();
		$_choice = new Choice();
		$_profile = new Profile();

		if($sesion_completion_id != null) {
			$args['completion_id'] = $sesion_completion_id;
		}

		$GLOBALS['entusiastics_quiz_game_completion_id'] = $args['completion_id'];

		// only if the quiz is published on more than one page, store info about source url
		if(!empty($quiz->save_source_url)) {
			$args['source_url'] = esc_url_raw($_SERVER['HTTP_REFERER']);	
		}

		// now insert in completed
		if(!empty($args['completion_id'])) {

			$_completed->save($quiz->id, entusiastics_quiz_game_user_ip(), $args['user_id'], $args['output'],$args['source_url'], intval($args['completion_id']));

			$args['taking_id'] = $args['completion_id'];	

			unset($_SESSION['entusiastics_quiz_game_completion_id']);	

		} else {

			// normally this shouldn't happen, but just in case
			$answer_id = $_completed->saveRarely($quiz->id, entusiastics_quiz_game_user_ip(), $args['user_id'], $args['output'], $args['source_url']);

			$args['taking_id'] = $answer_id;

		}

		// send API call for other plugins
		do_action('entusiastics_quiz_game_quiz_completed', $args['taking_id']);

		$args['completed'] = $_completed->getCompletedById(intval($args['taking_id']));

		$args['user_answers'] = $_user_answer->getUserAnswerByCompletionId(intval($args['completed']->id));

		$quiz = [];

		foreach ($args['user_answers'] as $key => $item) {
			$quiz = $_quiz->getQuizById($item->quiz_id);
			$args['results'][$key]['quiz'] = $_quiz->getQuizById($item->quiz_id);
			$args['results'][$key]['question']=  $_question->getQuestionById(intval($item->question_id));

			if($args['results'][$key]['question']->qtype == 'checkbox') {
				$args['results'][$key]['answers'] = $_choice->getMultipleAnswerById($item->answer);
				$args['results'][$key]['profile'] = [];
				$args['results'][$key]['answer'] = [];
			} else {
				$args['results'][$key]['profile']=  $_profile->getProfileById(intval($item->profile_id));
				$args['results'][$key]['answer'] =  $_choice->getAnswerById(intval($item->answer));
			}
		}

		$args['quiz'] = $quiz;

		$args['results_positive'] = [];
		$args['results_negative'] = [];
		$args['results_no_profile'] = [];

		foreach ($args['results'] as $key => $result) {

			if($result['question']->qtype == 'checkbox') {

				foreach ($result['answers'] as $choice) {

					$profile = $_profile->getProfileById($choice->profile_id);

					if($profile->connotation == '1') {

						$result['profile'] = $profile;
						$result['answer'] = $choice;
						$args['results_positive'][$key] = $result;
						

					} elseif($profile->connotation == '0') {

						$result['profile'] = $profile;
						$result['results']['answer'][$key] = $choice;
						$args['results_negative'][$key] = $result;
						
					} else {

						$result['profile'] = $profile;
						$result['answer'] = $choice;
						$args['results_no_profile'][$key] = $result;
					}
				}	

			} else {

				if($result['profile']->connotation == '1') {

					$args['results_positive'][$key] = $result;

				} elseif($result['profile']->connotation == '0') {

					$args['results_negative'][$key] = $result;

				} else {

					$args['results_no_profile'][$key] = $result;

				}

			}

		}

		$args['redirect_url'] = entusiastics_quiz_game_get_url_shortcode_landing();

		echo '|ENTUSIASTICSQUIZGAME|';

		do_action('entusiastics_show_result_template', 'result', $args);

   } // end finalize

   public function delete() {

   	$_quiz = new Quiz();

   	$action = filter_input(INPUT_GET, 'action');
   	$quiz_id = filter_input(INPUT_GET, 'id');

   	if(!empty($action)){

   		$_quiz->delete($quiz_id);

   		$delete_msg = 'ok';

   		entusiastics_quiz_game_redirect("admin.php?page=entusiastics-quiz-game-quizzes-list");
   	}

   }

   public function copy() {

   	$_quiz = new Quiz();

   	$action = filter_input(INPUT_GET, 'action');
   	$quiz_id = filter_input(INPUT_GET, 'id');

   	if(!empty($action)){

   		$_quiz->copy($quiz_id);

   		$copy_msg = 'ok';

   		entusiastics_quiz_game_redirect("admin.php?page=entusiastics-quiz-game-quizzes-list");
   	}

   }
   
}