<?php

/**
 * Profile Model
 *
 *
 * @link       https://entusiastics.com
 * @since      1.0.0
 *
 * @package    Entusiastics_Quiz_Game
 * @subpackage Entusiastics_Quiz_Game/admin/models
 */

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class UserAnswer {

	/**
	 * Get all User Answers
	 *
	 * @return 	array Array of next question and this choices
	 */
	public function getAll() {

		global $wpdb;

		$order_by = 'id';

		$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_USER_ANSWERS." ORDER BY %s", $order_by);
		$user_answers = $wpdb->get_results($sql);

		return $user_answers;
	}

	/**
	 * Get User Answers by Completion ID
	 *
	 * @return 	array Array of next question and this choices
	 */
	public function getUserAnswerByCompletionId($completed_id) {

		global $wpdb;

		$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_USER_ANSWERS." WHERE completion_id=%d ORDER BY id", $completed_id);
		$user_answers = $wpdb->get_results($sql);

		return $user_answers;
	}

	public function checkIfAnswerExists($quiz_id, $session, $question_id){

		global $wpdb;

		$sql = $wpdb->prepare("SELECT id FROM ".ENTUSIASTICS_QUIZ_GAME_USER_ANSWERS." WHERE quiz_id=%d AND completion_id=%d AND question_id=%d", $quiz_id, $session, $question_id);
		$exists = $wpdb->get_var($sql);

		return $exists;
	}
	
	public function update($answer, $quiz_id, $session, $question_id, $profile_id) {

		global $wpdb;

		$updated = $wpdb->query($wpdb->prepare("UPDATE ".ENTUSIASTICS_QUIZ_GAME_USER_ANSWERS." SET answer=%s, profile_id=%s WHERE quiz_id=%d AND completion_id=%d AND question_id=%d", $answer, $profile_id, $quiz_id, $session, $question_id));

		return $updated;

	} // end update
	
	public function save($quiz_id, $session, $question_id, $answer, $profile_id) {

		global $wpdb;

		$stored = $wpdb->query($wpdb->prepare("INSERT INTO ".ENTUSIASTICS_QUIZ_GAME_USER_ANSWERS." SET quiz_id=%d, completion_id=%d, question_id=%d, answer=%s, profile_id=%d", $quiz_id, $session, $question_id, $answer, $profile_id));

		return $stored;

	} // end save
	
	public function delete($id) {

	} // end delete

} 