<?php

/**
 * The template for game front page.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package Entusiastics_Quiz_Game
 * @subpackage Entusiastics_Quiz_Game/public/templates
 */

if ( ! defined( 'ABSPATH' ) ) { exit; } // Exit if accessed directly 

?>

<div class="entusiastic-question-header" style="background-color: <?php echo $args['quiz']->theme_color ?>">

	<div class="entusiastic-question-header-wrapper">

		<div class="entusiastic-question-header-inner">

			<div class="entusiastic-question-title">
				<h1 class="entusiastic-question-title-text">
					<?php echo $args['quiz']->title ?>
				</h1>
			</div>

			<div class="entusiastic-question-close">
				<a id="entusiastics-close-quiz-button" href="#" class="entusiastic-question-cross"></a>
			</div>

		</div>

	</div>

</div>

<div class="entusiastics-result-container">

	<div class="entusiastics-result-wrapper">

		<div class="entusiastics-result-title-wrapper">
			<h2 class="entusiastics-result-title">
				<?php _e('Resultados', 'entusiastics-quiz-game') ?>
			</h2>
		</div>

		<div class="entusiastics-result-content">
			<input type="hidden" id="minus-info-text" value="<?php _e('Menos info', 'entusiastics-quiz-game'); ?>" />
			<input type="hidden" id="more-info-text" value="<?php _e('Más info', 'entusiastics-quiz-game'); ?>" />

			<?php include 'partials/result-positive.php'; ?>

			<?php include 'partials/result-negative.php'; ?>

			<?php if(!empty($args['results_no_profile'])) { 
				include 'partials/result-no_profile.php';
			} ?>

		</div>

	</div>

</div>

<style>
	.back-to-games-button {
		background-color: transparent;
		color: <?php echo $args['quiz']->theme_color ?>;
		border: 1px solid <?php echo $args['quiz']->theme_color ?>;
		
	}
	.download-button {
		background-color: <?php echo $args['quiz']->theme_color ?>;
		border: 1px solid <?php echo $args['quiz']->theme_color ?>;
		color: #FFF;
	}
	.back-to-games-button:hover {
		background-color: <?php echo $args['quiz']->theme_color ?>;
		color: #FFF;
	}
	.download-button:hover {
		background-color: transparent;
		color: <?php echo $args['quiz']->theme_color ?>;
	}
</style>

<div class="entusiastics-result-button-container">

	<div class="entusiastics-result-button-wrapper">

		<a id="entusiastics-result-button" href="<?php echo $args['redirect_url'] != '' ? $args['redirect_url'] : '/'; ?>" class="back-to-games-button">
			<?php _e('Volver a los Juegos', 'entusiastics-quiz-game') ?>
		</a>

		<a id="entusiastics-download-result-button" href="#" class="download-button" style="display:none;">
			<?php _e('Descargar resultados', 'entusiastics-quiz-game') ?>
		</a>
		
	</div>

</div>

<?php include 'partials/question-modal-result.php'; ?>

<script>
	jQuery(document).ready(function() {

		var height = jQuery('.entusiastic-question-header').height() + 50;
		jQuery('.entusiastics-result-container').css('padding-top', height);

		jQuery( ".donut-size" ).each(function(index){

			item_id = jQuery( this ).attr('id');
			item_percentage = jQuery( this ).attr('data-percent');

			updateDonutChart( '#'+item_id, item_percentage, true);

		});		

		var acc = document.getElementsByClassName("entusiastics-indicator-accordion-button");
		var i;

		for (i = 0; i < acc.length; i++) {

			acc[i].addEventListener("click", function(e) {

				e.preventDefault();

				var text = jQuery(this).children('.entusiastics-indicator-accordion-button-text');
				var icon = jQuery(this).children('.entusiastics-indicator-accordion-button-icon');

				var minus_text = jQuery('#minus-info-text').val();
				var more_text = jQuery('#more-info-text').val();

				jQuery(this).toggleClass("active");

				var panel = jQuery(this).parent().parent().siblings('.entusiastics-indicator-item-bottom').find('.entusiastics-indicator-item-panel');

				if (jQuery(panel).css('max-height') != '0px') {

					jQuery(panel).css('max-height', '0px');
					text.html(more_text);
					icon.text('+');

				} else {

					jQuery(panel).css('max-height', jQuery(panel).prop("scrollHeight") +'px');
					text.html(minus_text);
					icon.text('-');

				}

			});

		}

		// Update Donut Chart
		function updateDonutChart (el, percent, donut) {

			percent = Math.round(percent);

			if (percent > 100) {
				percent = 100;
			} else if (percent < 0) {
				percent = 0;
			}
			var deg = Math.round(360 * (percent / 100));

			if (percent > 50) {
				jQuery(el + ' .pie').css('clip', 'rect(auto, auto, auto, auto)');
				jQuery(el + ' .right-side').css('transform', 'rotate(180deg)');
			} else {
				jQuery(el + ' .pie').css('clip', 'rect(0, 1em, 1em, 0.5em)');
				jQuery(el + ' .right-side').css('transform', 'rotate(0deg)');
			}

			if (donut) {
				jQuery(el + ' .right-side').css('border-width', '0.1em');
				jQuery(el + ' .left-side').css('border-width', '0.1em');
				jQuery(el + ' .shadow').css('border-width', '0.1em');
			} else {
				jQuery(el + ' .right-side').css('border-width', '0.5em');
				jQuery(el + ' .left-side').css('border-width', '0.5em');
				jQuery(el + ' .shadow').css('border-width', '0.5em');
			}

			jQuery(el + ' .left-side').css('transform', 'rotate(' + deg + 'deg)');
		}

	});
</script>